import json
import os
from tempfile import NamedTemporaryFile

import delegator

import pytest

STORYSCRIPT_CONFIG = {
    'id': os.environ['STORYSCRIPT_INT_CONF_USER_ID'],
    'access_token': os.environ['STORYSCRIPT_INT_CONF_ACCESS_TOKEN']
}


@pytest.fixture
def cli():
    def function(*args, logged_in=True):

        tf = NamedTemporaryFile().name

        if logged_in:
            # Create a temporary config file.
            with open(tf, 'w') as f:
                f.write(json.dumps(STORYSCRIPT_CONFIG))

        # Make temporary file.
        args = ' '.join(args)
        c = delegator.run(f'story {args}', env={'TOXENV': 'true',
                                                'STORY_CONFIG_PATH': tf})

        os.remove(tf)
        return c

    return function


@pytest.fixture
def app_dir():
    pass



import os
from tempfile import mkdtemp

import pytest


def test_bare_apps(cli):
    c = cli('apps')
    assert 'Usage' in c.out


def test_apps_create(cli):
    # Make a temporary directory to
    loc = mkdtemp()
    os.makedirs(loc, exist_ok=True)

    old_location = os.curdir
    os.chdir(loc)

    # Create the application.
    c = cli('apps', 'create')

    # Destroy the application.
    cli('apps', 'destroy')

    # Switch back to previous directory.
    os.chdir(old_location)

    assert 'Creating' in c.out
    assert c.return_code == 0



import os
from tempfile import NamedTemporaryFile

import pytest


def test_write_no_story(cli):
    c = cli('write')
    assert c.return_code == 1
    assert 'Please specify a template' in c.out


story_params = (
    'story,expected',
    [
        ('http', 'http'),
        ('function', 'function'),
        ('if', 'if'),
        ('loop', 'for'),
    ],
)


@pytest.mark.parametrize(*story_params)
def test_write_specified_story(cli, story, expected):
    # Test bare argument.
    c = cli('write', story)
    assert expected in c.out
    assert c.return_code == 0


@pytest.mark.parametrize(*story_params)
def test_write_specified_story_with_path(cli, story, expected):
    tf = NamedTemporaryFile()

    c = cli('write', story, tf.name)
    assert expected in c.out
    assert c.return_code == 0

    # Cleanup the temporary files.
    os.remove(tf.name)


def test_help(cli):
    # Test bare argument.
    c = cli('--help')
    assert 'Commands' in c.out
    assert c.return_code == 0


@pytest.mark.skip
def test_completion(cli):
    c = cli('completion')
    assert 'complete' in c.out


def test_support(cli):
    c = cli('--support')
    assert 'argv' in c.out
